==> haskell-mime-types-0.1.0.9-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-types
version:              0.1.0.9
visibility:           public
id:                   mime-types-0.1.0.9-CSw2q48Sh6O8K1mSyOSTlO
key:                  mime-types-0.1.0.9-CSw2q48Sh6O8K1mSyOSTlO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.

category:             Web
abi:                  13fd52622f5e1ff230fabc61673c35da
exposed:              True
exposed-modules:      Network.Mime
import-dirs:          /usr/lib/ghc-8.8.1/site-local/mime-types-0.1.0.9
library-dirs:         /usr/lib/ghc-8.8.1/site-local/mime-types-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/mime-types-0.1.0.9
hs-libraries:         HSmime-types-0.1.0.9-CSw2q48Sh6O8K1mSyOSTlO
depends:
    base-4.13.0.0 bytestring-0.10.9.0 containers-0.6.2.1 text-1.2.4.0

haddock-interfaces:   /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html:         /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-types-0.1.0.9-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-types
version:              0.1.0.9
visibility:           public
id:                   mime-types-0.1.0.9-BmYfzyhw3lzKyT3NNKO3PS
key:                  mime-types-0.1.0.9-BmYfzyhw3lzKyT3NNKO3PS
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.

category:             Web
abi:                  14f18b0bcc0af79c475cdde7971ddeb4
exposed:              True
exposed-modules:      Network.Mime
import-dirs:          /usr/lib/ghc-8.8.3/site-local/mime-types-0.1.0.9
library-dirs:         /usr/lib/ghc-8.8.3/site-local/mime-types-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/mime-types-0.1.0.9
hs-libraries:         HSmime-types-0.1.0.9-BmYfzyhw3lzKyT3NNKO3PS
depends:
    base-4.13.0.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.4.0

haddock-interfaces:   /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html:         /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
